==> haskell-hspec-attoparsec-0.1.0.2-284.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-8nLjJ04O4532dpJTmuTXQs
key:                  hspec-attoparsec-0.1.0.2-8nLjJ04O4532dpJTmuTXQs
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  d42962cc8ec1a22c7c0f152c6e2b81c9
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-attoparsec-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-attoparsec
hs-libraries:         HShspec-attoparsec-0.1.0.2-8nLjJ04O4532dpJTmuTXQs
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 hspec-expectations-0.8.4-7xRGbz7YGlh8mVR0kjpKwh
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-attoparsec-0.1.0.2-285-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-9miYMMZZ6xg13H1hzOSqQr
key:                  hspec-attoparsec-0.1.0.2-9miYMMZZ6xg13H1hzOSqQr
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  4dbd3b7feaac451969a215349aa41477
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-attoparsec-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-attoparsec
hs-libraries:         HShspec-attoparsec-0.1.0.2-9miYMMZZ6xg13H1hzOSqQr
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
